@@ -11,7 +11,7 @@ import mobster.utils_mobster as mut
 
 @config_enumerate
 def guide(data, K=1, tail=1, purity=0.96, clonal_beta_var=1., alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=100.,
-          number_of_trials_clonal=900., number_of_trials_k=300., prior_lims_clonal=[1., 10000.],
+          number_of_trials_clonal=900., number_of_trials_k=300., prior_lims_clonal=[1., 10000.],alpha_precision_concentration = 5, alpha_precision_rate=0.05,
           prior_lims_k=[1., 10000.]):
     """
     Parameters
@@ -39,6 +39,14 @@ def guide(data, K=1, tail=1, purity=0.96, clonal_beta_var=1., alpha_prior_concen
 
     a_prior = pyro.param("tail_mean", torch.tensor(1.5), constraint=constraints.interval(0.5, 5))
     sd_prior = pyro.param("tail_sd",dist.Gamma(concentration=alpha_prior_concentration, rate=alpha_prior_rate).mean, constraint=constraints.positive)
+    alpha_precision = pyro.param("alpha_noise",
+                                 dist.Gamma(concentration=alpha_precision_concentration, rate=alpha_precision_rate).mean * torch.ones([len(karyos)]),
+                                 constraint=constraints.positive)
+
+
+
+    alpha_precision = pyro.sample('alpha_precision', dist.Delta(alpha_precision))
+
 
     alpha_prior_sd = pyro.sample('sd_tail', dist.Delta(sd_prior))
 
@@ -60,7 +68,9 @@ def guide(data, K=1, tail=1, purity=0.96, clonal_beta_var=1., alpha_prior_concen
 
     for kr in pyro.plate("kr", len(karyos)):
 
-        pyro.sample('alpha_{}'.format(kr), dist.LogNormal(torch.log(alpha_prior), alpha_prior_sd))
+        alpha_teo = pyro.sample('alpha_{}'.format(kr), dist.LogNormal(torch.log(alpha_prior) * mut.theo_allele_list[karyos[kr]], alpha_prior_sd))
+        torch.abs(alpha_teo + pyro.sample("alpha_noise_{}".format(kr), dist.Normal(torch.zeros_like(alpha_teo),1/alpha_precision[kr])))
+
 
         if theoretical_num_clones[kr] == 2:
 
