@@ -12,12 +12,20 @@ theo_clonal_list = {
     "2:2" : 2
 }
 
+theo_allele_list = {
+    "1:0" : 1,
+    "1:1" : 2,
+    "2:0" : 2,
+    "2:1" : 3,
+    "2:2" : 4
+}
+
 theo_clonal_means_list = {
     "1:0" : 0.99999,
     "1:1" : 0.5,
-    "2:0" : torch.tensor([0.5,0.99999], dtype=torch.float32),
-    "2:1" : torch.tensor([0.333,0.666], dtype=torch.float32),
-    "2:2" : torch.tensor([0.25,0.5], dtype=torch.float32)
+    "2:0" : torch.tensor([0.5,0.99999]),
+    "2:1" : torch.tensor([0.333,0.666]),
+    "2:2" : torch.tensor([0.25,0.5])
 }
 
 def flatten_list(l):
@@ -100,6 +108,7 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
         res["tail_shape"] = params['tail_mean'].detach().numpy()
         res["tail_scale"] = np.min(data[k].detach().numpy())
         res["tail_shape_sd"] = params['tail_sd'].detach().numpy()
+        res["tail_noise"] =  params['alpha_noise'][i].detach().numpy()
 
     return res
 
